@@ -470,6 +470,14 @@ class WSGIComboTest(ComboTestBase, mocker.MockerTestCase):
             ["yui/yui-min.js"])), status=200)
         self.assertEquals(res.body.strip(), expected2)
 
+    def test_path_hint_cant_break_root(self):
+        """You should not be able to get outside of the root via path hint."""
+        app = TestApp(combo_app('/tmp'))
+
+        # we attempt to use the path hint to reassign root to /etc
+        # and ask for passwd, it's inside the new adjusted root
+        app.get("/../etc?yui-min&passwd", status=400)
+
 
 def test_suite():
     return defaultTestLoader.loadTestsFromName(__name__)
